"""myhome provides a client library for interacting with Bticino MYHOMESERVER1 via its built-in RESTful API.

This API is used by the MyHomeUp mobile application as well and allows full
control of the underlying home automation bus.

The intention here is to provide an implementation of a client library
based on the reverse-engineering network interactions, which are documented
at https://github.com/speijnik/myhome/tree/main/doc/
"""

__version__ = "0.1.0"
