"""
    MyHomeSERVER1 API

    API provided by the Bticino MyHomeSERVER1 system and used by the MyHomeUp mobile application  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import myhome._gen
from myhome._gen.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_actual_user(self):
        """Test case for get_actual_user

        Retrieves current user's ID  # noqa: E501
        """
        pass

    def test_get_object_list(self):
        """Test case for get_object_list

        Retrieves list of objects (devices)  # noqa: E501
        """
        pass

    def test_get_object_value(self):
        """Test case for get_object_value

        Retrieves current object value  # noqa: E501
        """
        pass

    def test_get_role_user(self):
        """Test case for get_role_user

        Retrieves user's role  # noqa: E501
        """
        pass

    def test_get_room_list(self):
        """Test case for get_room_list

        Retrieves list of rooms  # noqa: E501
        """
        pass

    def test_get_scene_list(self):
        """Test case for get_scene_list

        Retrieves list of scenes (actions)  # noqa: E501
        """
        pass

    def test_get_serial_server(self):
        """Test case for get_serial_server

        Retrieves system serial number  # noqa: E501
        """
        pass

    def test_get_system_info(self):
        """Test case for get_system_info

        Retrieves basic system information  # noqa: E501
        """
        pass

    def test_get_zone_list(self):
        """Test case for get_zone_list

        Retrieves list of zones  # noqa: E501
        """
        pass

    def test_init_check(self):
        """Test case for init_check

        Checks if system has fully started  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        Authenticates with the MyHomeSERVER1 system  # noqa: E501
        """
        pass

    def test_set_object_value(self):
        """Test case for set_object_value

        Retrieves current object value  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
